@@ -1,5 +1,5 @@
 #!/usr/local/bin/ruby
-# $Id: test.rb 213 2008-03-07 16:30:47Z tommy $
+# $Id: test.rb 220 2008-06-17 05:45:58Z tommy $
 
 require "test/unit"
 require "./mysql.o"
@@ -16,7 +16,7 @@ class TC_Mysql < Test::Unit::TestCase
   end
 
   def test_version()
-    assert_equal(20705, Mysql::VERSION)
+    assert_equal(20706, Mysql::VERSION)
   end
 
   def test_init()
@@ -681,6 +681,17 @@ class TC_MysqlStmt2 < Test::Unit::TestCase
     end
   end
 
+  def test_execute5()
+    if @m.server_version >= 40100 then
+      [30, 31, 32, 62, 63].each do |i|
+        v, = @m.prepare("select cast(? as signed)").execute(2**i-1).fetch
+        assert_equal(2**i-1, v)
+        v, = @m.prepare("select cast(? as signed)").execute(-(2**i)).fetch
+        assert_equal(-(2**i), v)
+      end
+    end
+  end
+
   def test_fetch()
     if @m.server_version >= 40100 then
       @s.prepare("select 123, 'abc', null")
